@@ -304,7 +304,7 @@ async def new(ctx: Context, force):
     try:
         workflow = await Workflow.new(project, force)
         workflow.show()
-    except WorkflowAlreadyExists as e:
+    except (WorkflowAlreadyExists, Exception) as e:
         click.echo(f"Error: {e}")
 
 
