@@ -18,12 +18,17 @@ class InitStage(BaseStage):
         resource_array = []
 
         for resource in resources:
-            resource_array.append(
-                {
-                    "file": resource.file,
-                    "num_trans_units": resource.get_num_trans_units(),
-                }
-            )
+            try:
+                resource_array.append(
+                    {
+                        "file": resource.file,
+                        "num_trans_units": resource.get_num_trans_units(),
+                    }
+                )
+            except Exception as e:
+                print("Error in file", resource.file, ":", str(e))
+                print("Please solve the problem and reset the workflow.")
+                return {}
 
         versions_dir = {
             "pangeamt_nlp": pangeamt_nlp.__version__,
